build_authorize_request_for_provider

Function build_authorize_request_for_provider 

pub fn build_authorize_request_for_provider(
    provider: CloudProvider,
    redirect_uri: &str,
) -> Result<AuthorizeRequest, OAuthError>
Build an OAuth authorization request for provider redirecting to redirect_uri, for hosts that capture the redirect themselves (a mobile OS auth session). Pair the returned request, callback code, callback state, and same redirect_uri with exchange_code_for_provider.

The provider configuration and this function are gated on oauth-providers.