pub fn cloud_account_display_for(
config: &Config,
key_service: &KeyService,
) -> Option<String>Expand description
Get a display string for the current cloud account (bucket name, username, etc.)
pub fn cloud_account_display_for(
config: &Config,
key_service: &KeyService,
) -> Option<String>Get a display string for the current cloud account (bucket name, username, etc.)