pub async fn create_sync_storage(
config: &Config,
key_service: &KeyService,
encryption_service: &Option<EncryptionService>,
clock: ClockRef,
) -> Result<EncryptedSyncStorage, String>Expand description
Create sync storage from config and credentials.
This is a lighter version of sync::cycle::init_sync that only creates the
storage client without starting a sync session or extracting raw DB handles.
Used by membership management which only needs storage access.