pub struct ExactObjectRef { /* private fields */ }Expand description
Exact stored representation of one immutable object.
Implementations
Sourceimpl ExactObjectRef
impl ExactObjectRef
pub fn new( slot: ObjectSlot, stored_size: u64, stored_hash: ObjectHash, ) -> ExactObjectRef
pub fn slot(&self) -> &ObjectSlot
pub fn stored_size(&self) -> u64
pub fn stored_hash(&self) -> ObjectHash
pub fn verify(&self, bytes: &[u8]) -> Result<(), StorageError>
Sourcepub fn verify_stored_facts(
&self,
path: &Path,
size: u64,
hash: ObjectHash,
) -> Result<(), StorageError>
pub fn verify_stored_facts( &self, path: &Path, size: u64, hash: ObjectHash, ) -> Result<(), StorageError>
Check independently computed file facts against the stored identity. Reading the file and computing its facts is the filesystem owner’s operation; this value only compares.