pub struct LiveQueryRequests<Request> { /* private fields */ }Expand description
Changes the absolute request evaluated by a reconfigurable live query.
Implementations
Sourceimpl<Request> LiveQueryRequests<Request>
impl<Request> LiveQueryRequests<Request>
Sourcepub fn set(
&self,
request: Request,
) -> Result<LiveQueryRevision, LiveQueryClosed>
pub fn set( &self, request: Request, ) -> Result<LiveQueryRevision, LiveQueryClosed>
Replace the requested value and return the revision that will deliver it.
Repeating the current request returns its existing revision. The call fails after the subscription has been dropped.