pub struct SyncCycleResult {
pub changesets_applied: u64,
pub other_device_count: usize,
pub sync_time: String,
pub asset_downloads_failed: bool,
pub row_changes: Vec<RowChange>,
}Expand description
Result of a single sync cycle.
Fields
changesets_applied: u64Number of remote changesets that were applied.
other_device_count: usizeNumber of other devices seen in the sync storage.
sync_time: StringRFC 3339 timestamp of when this cycle completed.
asset_downloads_failed: boolAsset downloads failed — cursor not advanced for those changesets.
row_changes: Vec<RowChange>Row changes from applied changesets, for the host to map to domain events.