pub async fn unwrap_library_key(
cloud_home: &dyn CloudHome,
keypair: &UserKeypair,
) -> Result<[u8; 32], InviteError>Expand description
Accept an invitation by downloading and unwrapping the library encryption key.
The invitee calls this after receiving an invitation. It downloads the wrapped key from cloud storage and decrypts it with the inviteeās X25519 keys.