remove_member

Function remove_member 

pub async fn remove_member(
    storage: &dyn SyncStorage,
    cloud_home: &dyn CloudHome,
    user_keypair: &UserKeypair,
    hlc: &Hlc,
    public_key_hex: &str,
) -> Result<[u8; 32], MembershipOpsError>
Remove a member from the shared library.

Downloads the membership chain, creates a signed Remove entry, rotates the encryption key, re-wraps it for remaining members, and returns the new encryption key bytes. The caller is responsible for persisting the new key to the keyring and updating config.