restore_from_cloud

Function restore_from_cloud 

pub async fn restore_from_cloud(
    library_id: &str,
    encryption_key_hex: &str,
    library_name: &str,
    source: RestoreSource,
    app_dir: &Path,
    clock: ClockRef,
    ids: IdRef,
    make_blob_plan: impl Fn(&LibraryDir) -> Box<dyn BlobPlan>,
    on_status: impl Fn(&str),
) -> Result<Config, RestoreError>
Restore a library from cloud storage.

Validates inputs, constructs the cloud home from the source, runs the sync protocol, and sets the library as active.