pub struct ConflictContext { /* private fields */ }Expand description
Context available to a conflict handler during changeset application.
Wraps the raw sqlite3_changeset_iter to provide safe access to the
table name, column count, and column values involved in a conflict.
Implementations
Sourceimpl ConflictContext
impl ConflictContext
Sourcepub fn table_name(&self) -> &str
pub fn table_name(&self) -> &str
The table name for this conflict’s operation.
Sourcepub fn column_count(&self) -> usize
pub fn column_count(&self) -> usize
The number of columns in this table.
Sourcepub fn new_value(&self, col: usize) -> Option<String>
pub fn new_value(&self, col: usize) -> Option<String>
Get the “new” value for a column (the incoming value from the changeset). Available for DATA and CONSTRAINT conflicts. Returns None if the column was not changed or the value is NULL.
Sourcepub fn conflict_value(&self, col: usize) -> Option<String>
pub fn conflict_value(&self, col: usize) -> Option<String>
Get the “conflict” value for a column (the current local value). Available for DATA and CONFLICT conflicts.