pub struct SqlContext<'ctx, 'conn> { /* private fields */ }Expand description
Host SQL inside one journaled write transaction.
The context exposes SQL operations, but never the underlying SQLite connection or transaction. In particular, a host cannot remove coven’s SQL authorizer and address its attached gate baseline:
ⓘ
handle.sql(|sql| {
sql.tx().authorizer(
None::<fn(coven::rusqlite::hooks::AuthContext<'_>)
-> coven::rusqlite::hooks::Authorization>,
)?;
Ok(())
}).await?;Implementations
Sourceimpl<'ctx, 'conn> SqlContext<'ctx, 'conn>
impl<'ctx, 'conn> SqlContext<'ctx, 'conn>
Sourcepub fn execute<P>(&self, sql: &str, params: P) -> Result<usize>where
P: Params,
pub fn execute<P>(&self, sql: &str, params: P) -> Result<usize>where
P: Params,
Execute one SQL statement with bound parameters.
Sourcepub fn execute_batch(&self, sql: &str) -> Result<()>
pub fn execute_batch(&self, sql: &str) -> Result<()>
Execute one or more semicolon-separated SQL statements.
Sourcepub fn query_row<T, P, F>(&self, sql: &str, params: P, map: F) -> Result<T>where
P: Params,
F: FnOnce(&Row<'_>) -> Result<T>,
pub fn query_row<T, P, F>(&self, sql: &str, params: P, map: F) -> Result<T>where
P: Params,
F: FnOnce(&Row<'_>) -> Result<T>,
Query exactly one row and map it to a host value.
Sourcepub fn query<T, P, F>(&self, sql: &str, params: P, map: F) -> Result<Vec<T>>where
P: Params,
F: FnMut(&Row<'_>) -> Result<T>,
pub fn query<T, P, F>(&self, sql: &str, params: P, map: F) -> Result<Vec<T>>where
P: Params,
F: FnMut(&Row<'_>) -> Result<T>,
Query any number of rows and collect their mapped host values.
pub fn stamp(&self) -> String