pub struct SyncSession { /* private fields */ }Expand description
A sync session that tracks changes to all synced tables on a single connection.
Lifecycle:
SyncSession::start(db)– creates and attaches- App writes normally through the connection
session.changeset()– grabs the binary diff (None if no changes)- Session is dropped (or explicitly ended by dropping)
The session must be dropped before applying incoming changesets to avoid contaminating the next outgoing changeset with other devices’ changes.
Implementations
Sourceimpl SyncSession
impl SyncSession